@@ -1028,7 +1028,7 @@ clutter_gst_video_sink_set_caps (GstBaseSink *bsink,
   const GValue               *par;
   gint                        width, height;
   guint32                     fourcc;
-  guint                       red_mask, blue_mask;
+  int                         red_mask, blue_mask;
 
   sink = CLUTTER_GST_VIDEO_SINK(bsink);
   priv = sink->priv;
@@ -1094,8 +1094,8 @@ clutter_gst_video_sink_set_caps (GstBaseSink *bsink,
   else
     {
       guint32 mask;
-      gst_structure_get_uint (structure, "red_mask", &red_mask);
-      gst_structure_get_uint (structure, "blue_mask", &blue_mask);
+      gst_structure_get_int (structure, "red_mask", &red_mask);
+      gst_structure_get_int (structure, "blue_mask", &blue_mask);
 
       mask = red_mask | blue_mask;
       if (mask < 0x1000000)
@@ -1189,7 +1189,6 @@ clutter_gst_video_sink_set_texture (ClutterGstVideoSink *sink,
           g_signal_handler_disconnect (priv->texture, id);
         }
       g_array_set_size (priv->signal_handler_ids, 0);
-      g_object_unref (priv->texture);
     }
 
   priv->texture = texture;
@@ -1219,7 +1218,7 @@ clutter_gst_video_sink_set_property (GObject *object,
   switch (prop_id)
     {
     case PROP_TEXTURE:
-      clutter_gst_video_sink_set_texture (sink, g_value_dup_object (value));
+      clutter_gst_video_sink_set_texture (sink, g_value_get_object (value));
       break;
     case PROP_UPDATE_PRIORITY:
       clutter_gst_video_sink_set_priority (sink, g_value_get_int (value));
